@@ -1,6 +1,7 @@
 import os
 
-from djangomaster.urls import urlpatterns
+from djangomaster.core import autodiscover
+from djangomaster.sites import mastersite
 
 
 def get_version():
@@ -12,6 +13,7 @@ __version__ = get_version()
 
 
 def get_urls():
-    return urlpatterns, 'djangomaster', 'djangomaster'
+    autodiscover()
+    return mastersite.urlpatterns, 'djangomaster', 'djangomaster'
 
 urls = get_urls()
